@@ -379,13 +379,13 @@ class OrderDataset(Dataset):
         # if data_col.dtype == "int64":
         #     return data_col.astype(int).max() + 1
         if col == self.ctx_cols[0]:
-            return self.ctx_np[:, 0].astype(int).max() + 1
+            return int(self.ctx_np[:, 0].astype(int).max() + 1)
         elif col == self.ctx_cols[1]:
-            return self.ctx_np[:, 1].astype(int).max() + 1
+            return int(self.ctx_np[:, 1].astype(int).max() + 1)
         elif col == self.ctx_cols[2]:
-            return self.ctx_np[:, 2].astype(int).max() + 1
+            return int(self.ctx_np[:, 2].astype(int).max() + 1)
         elif col == self.seq_col:
-            return max(int(self.seq_np.reshape(-1).max()), int(self.candidate_np.reshape(-1).max())) + 1
+            return int(max(int(self.seq_np.reshape(-1).max()), int(self.candidate_np.reshape(-1).max())) + 1)
         # elif data_col.dtype == "object":
         #     return int(np.array(data_col.to_list()).max()) + 1
         else:
